---
title: <span class="badge builder"></span> DashboardSpecialValueMapOptions
---
# <span class="badge builder"></span> DashboardSpecialValueMapOptions

## Constructor

```python
DashboardSpecialValueMapOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.DashboardSpecialValueMapOptions
```

### <span class="badge object-method"></span> match

Special value to match against

```python
def match(match: dashboard.SpecialValueMatch) -> typing.Self
```

### <span class="badge object-method"></span> result

Config to apply when the value matches the special value

```python
def result(result: dashboard.ValueMappingResult) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DashboardSpecialValueMapOptions](./object-DashboardSpecialValueMapOptions.md)
